@@ -63,14 +63,9 @@
 #' Schmitt, Walter. "General approach for the calculation of tissue 
 #' to plasma partition coefficients." Toxicology in vitro 22.2 (2008): 457-467.
 #'
-#' Pearce, Robert G., et al. "Evaluation and calibration of high-throughput 
-#' predictions of chemical distribution to tissues." Journal of pharmacokinetics 
-#' and pharmacodynamics 44.6 (2017): 549-565.
+#' \insertRef{dawson2021qsar}{httk} 
 #'
-#' Kilford, P. J., Gertz, M., Houston, J. B. and Galetin, A.
-#' (2008). Hepatocellular binding of drugs: correction for unbound fraction in
-#' hepatocyte incubations using microsomal binding or drug lipophilicity data.
-#' Drug Metabolism and Disposition 36(7), 1194-7, 10.1124/dmd.108.020834.
+#' \insertRef{kilford2008hepatocellular}{httk} 
 #'
 #' @keywords Parameter  1compartment
 #' 
@@ -81,12 +76,13 @@
 #' calc_elimination_rate(chem.cas="80-05-7")
 #' 
 #' @export calc_elimination_rate
+
 calc_elimination_rate <- function(chem.cas=NULL,
                                   chem.name=NULL,
                                   dtxsid=NULL,
                                   parameters=NULL,
                                   species="Human",
-                                  suppress.messages=FALSE,
+                                  suppress.messages=TRUE,
                                   default.to.human=FALSE,
                                   restrictive.clearance=TRUE,
                                   adjusted.Funbound.plasma=TRUE,
@@ -126,6 +122,7 @@ calc_elimination_rate <- function(chem.cas=NULL,
                     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
                     clint.pvalue.threshold=clint.pvalue.threshold,
                     minimum.Funbound.plasma=minimum.Funbound.plasma)
+                    
     Vd <- calc_vdist(chem.cas=chem.cas,
                      chem.name=chem.name,
                      dtxsid=dtxsid,
