@@ -144,15 +144,21 @@ model.list[["1compartment"]]$dosing.params <- c(
 
 model.list[["1compartment"]]$routes <- list(
   "oral" = list(
-# We need to know which compartment gets the dose 
+    # We need to know which compartment gets the dose 
     "entry.compartment" = "Agutlumen",
-# desolve events can take the values "add" to add dose C1 <- C1 + dose,
-# "replace" to change the value C1 <- dose
-# or "multiply" to change the value to C1 <- C1*dose
-    "dose.type" = "add"),
+    # desolve events can take the values "add" to add dose C1 <- C1 + dose,
+    # "replace" to change the value C1 <- dose
+    # or "multiply" to change the value to C1 <- C1*dose
+    "dose.type" = "add",
+    "dosing.params" = c("daily.dose",
+                        "initial.dose",
+                        "doses.per.day",
+                        "dosing.matrix")),
   "iv" = list(
     "entry.compartment" = "Acompartment",
-    "dose.type" = "add")
+    "dose.type" = "add",
+    "dosing.params" = c("initial.dose",
+                        "dosing.matrix"))
   )
 
 # ORDERED LIST of state variables (must match Model variables: 
@@ -205,7 +211,8 @@ model.list[["1compartment"]]$firstpass <- TRUE
 model.list[["1compartment"]]$exclude.fup.zero <- TRUE
 
 # These are the parameter names needed to describe steady-state dosing:
-model.list[["1compartment"]]$css.dosing.params <- c("hourly.dose")
+model.list[["1compartment"]]$css.dosing.params <- list(
+  oral=c("hourly.dose"))
 
 # Filter out compounds belonging to select chemical classes
 model.list[["1compartment"]]$chem.class.filt <- c("PFAS")
