@@ -195,17 +195,22 @@ model.list[["3compartment"]]$dosing.params <- c(
   
 model.list[["3compartment"]]$routes <- list(
   "oral" = list(
-# We need to know which compartment gets the dose 
+    # We need to know which compartment gets the dose 
     "entry.compartment" = "Aintestine",
-# desolve events can take the values "add" to add dose C1 <- C1 + dose,
-# "replace" to change the value C1 <- dose
-# or "multiply" to change the value to C1 <- C1*dose
-    "dose.type" = "add"),
+    # desolve events can take the values "add" to add dose C1 <- C1 + dose,
+    # "replace" to change the value C1 <- dose
+    # or "multiply" to change the value to C1 <- C1*dose
+    "dose.type" = "add",
+    "dosing.params" = c("daily.dose",
+                        "initial.dose",
+                        "doses.per.day",
+                        "dosing.matrix")),
   "iv" = list(
     "entry.compartment" = "Asyscomp",
-    "dose.type" = "add")
-  )
-    
+    "dose.type" = "add",
+    "dosing.params" = c("initial.dose",
+                        "dosing.matrix"))
+  )    
 
 
 # ORDERED LIST of state variables (must match Model variables: 
@@ -268,7 +273,8 @@ model.list[["3compartment"]]$firstpass <- FALSE
 model.list[["3compartment"]]$exclude.fup.zero <- TRUE
 
 # These are the parameter names needed to describe steady-state dosing:
-model.list[["3compartment"]]$css.dosing.params <- c("hourly.dose")
+model.list[["3compartment"]]$css.dosing.params <- list(
+  oral=c("hourly.dose"))
 
 # Filter out volatile compounds with Henry's Law Constant Threshold
 model.list[["3compartment"]]$log.henry.threshold <- c(-4.5)
