@@ -248,10 +248,16 @@ model.list[["pbtk"]]$routes <- list(
 # desolve events can take the values "add" to add dose C1 <- C1 + dose,
 # "replace" to change the value C1 <- dose
 # or "multiply" to change the value to C1 <- C1*dose
-    "dose.type" = "add"),
+    "dose.type" = "add",
+"dosing.params" = c("daily.dose",
+                    "initial.dose",
+                    "doses.per.day",
+                    "dosing.matrix")),
   "iv" = list(
     "entry.compartment" = "Aven",
-    "dose.type" = "add")
+    "dose.type" = "add",
+    "dosing.params" = c("initial.dose",
+                       "dosing.matrix"))
   )
 
 # ORDERED LIST of state variables (must match Model variables: 
@@ -356,7 +362,8 @@ model.list[["pbtk"]]$firstpass <- FALSE
 model.list[["pbtk"]]$exclude.fup.zero <- TRUE
 
 # These are the parameter names needed to describe steady-state dosing:
-model.list[["pbtk"]]$css.dosing.params <- c("hourly.dose")
+model.list[["pbtk"]]$css.dosing.params <- list(
+  oral=c("hourly.dose"))
 
 # Filter out volatile compounds with Henry's Law Constant Threshold
 model.list[["pbtk"]]$log.henry.threshold <- c(-4.5)
