@@ -150,15 +150,16 @@
 #' @keywords Solve
 #'
 #' @examples
-#' # The varrious "solve_x" functions are wrappers for solve_model:
+#' # The various "solve_x" functions are wrappers for solve_model:
 #' head(solve_pbtk(chem.name="Terbufos", days=1))
 #'
-#' head(solve_model(chem.name="Terbufos",model="pbtk",dosing=list(
-#'                  initial.dose = 1, # Assume dose is in mg/kg BW/day  
-#'                  doses.per.day=NULL,
-#'                  dosing.matrix = NULL,
+#' head(solve_model(chem.name="Terbufos",model="pbtk",
 #'                  days=1,
-#'                  daily.dose = NULL)))
+#'                  dosing=list(
+#'                    initial.dose = 1, # Assume dose is in mg/kg BW/day  
+#'                    doses.per.day=NULL,
+#'                    dosing.matrix = NULL,
+#'                    daily.dose = NULL)))
 #'
 #' # A dose matrix specifies times and magnitudes of doses:
 #' dm <- matrix(c(0,1,2,5,5,5),nrow=3)
@@ -170,19 +171,23 @@
 #'            days=2.5,
 #'            daily.dose=NULL)
 #' 
-#' solve_model(chem.name="Methenamine",model="pbtk",dosing=list(
-#'             initial.dose =NULL,
-#'             doses.per.day=NULL,
-#'             daily.dose=NULL,
+#' solve_model(chem.name="Methenamine",
+#'             model="pbtk",
 #'             days=2.5,
-#'             dosing.matrix=dm))
+#'             dosing=list(
+#'               initial.dose =NULL,
+#'               doses.per.day=NULL,
+#'               daily.dose=NULL,
+#'               dosing.matrix=dm))
 #' 
-#' solve_model(chem.name="Besonprodil",model="pbtk",dosing=list(
-#'             initial.dose =NULL,
-#'             doses.per.day=4,
-#'             daily.dose=1,
+#' solve_model(chem.name="Besonprodil",
+#'             model="pbtk",
 #'             days=2.5,
-#'             dosing.matrix=NULL))
+#'             dosing=list(
+#'               initial.dose=NULL,
+#'               doses.per.day=4,
+#'               daily.dose=1,
+#'               dosing.matrix=NULL))
 #'   
 #' solve_pbtk(chem.name="Besonprodil",
 #'            daily.dose=1,
@@ -278,9 +283,6 @@ solve_model <- function(chem.name = NULL,
 # the names of the state variables of the model (so far, always in units of 
 # amounts)
     state.vars <- model.list[[model]]$state.vars
-# The names of the supported dosing parameters, the names of which must be 
-# specified to solve_model, even if corresponding to NULL values
-    dosing_params <- model.list[[model]]$dosing.params
 # name of function that initializes the compiled model code:
     initialize_compiled_function <- model.list[[model]]$compiled.init.func
 # name(s)s of the R parameters needed to initialize the compiled model params:
@@ -305,6 +307,8 @@ solve_model <- function(chem.name = NULL,
     initforc <- model.list[[model]]$forcings.materials[["initforc"]]
 # Using a forcings series also requires specifying fcontrol argument
     fcontrol <- model.list[[model]]$forcings.materials[["fcontrol"]]
+    # State of Compound in Various Compartments
+    compartment_state <- model.list[[model]]$compartment.state
   }
   
 
@@ -348,6 +352,9 @@ is not among those listed in compartment.units in modelinfo file for model",
           route))
       }
     }
+    # The names of the supported dosing parameters, the names of which must be 
+    # specified to solve_model, even if corresponding to NULL values
+    dosing_params <- model.list[[model]]$routes[[route]][["dosing.params"]]
   }
   
   #Make basic checks for variable name convention observance in objects of
@@ -586,6 +593,24 @@ specification in compartment_units for model ", model)
       given.units <- initial.value.units[this.compartment]
       # required model value units
       model.units <- compartment_units[this.compartment]
+      # compartment state for unit conversion
+      #
+      # First check if value "all" is used for a state (that is, all 
+      # compartments are the same state of matter):
+      if (all(tolower(compartment_state[[1]])%in%"all"))
+      {
+        model.compartment.state <- names(compartment_state)[1]
+      } else {
+        model.compartment.state.check <- unlist(lapply(compartment_state,function(x){this.compartment%in%x}))
+        if(any(model.compartment.state.check)){
+          model.compartment.state <- names(compartment_state)[which(model.compartment.state.check==TRUE)]
+        }else{
+          warning(paste0(this.compartment,
+                         " state is not specified in the model.list for ",model,
+                         ". Will assume the default, i.e. 'liquid'."))
+          model.compartment.state <- "liquid"
+        }
+      }
       
       # # (1) get all tissues with volume from param_names
       # all.tissue.vols <- param_names[grep(param_names,pattern = "^V.+c$")]
@@ -610,7 +635,8 @@ specification in compartment_units for model ", model)
       out.unit.conversion <- convert_units(
         input.units=given.units,
         output.units=model.units,
-        MW = MW) # ,
+        MW = MW,
+        state = model.compartment.state) # ,
         # vol = tissue.vol)
       
       return(out.unit.conversion)
@@ -631,7 +657,7 @@ specification in compartment_units for model ", model)
   SMALL.TIME <- 1e-3  
   
   # We need to let the solver know which time points we want:
-  if (is.null(times)) times <- round(seq(0, days, 1/(24*tsteps)),8)
+  if (is.null(times)) times <- seq(0, days, 1/(24*tsteps))
   times <- sort(times)
   start.time <- times[1]
   end.time <- times[length(times)]
@@ -649,8 +675,20 @@ specification in compartment_units for model ", model)
   # Make sure we have all specified dosing parameters for the model
   # accounted for
   if (!all(unique(dosing_params) %in% names(dosing)))
-    stop("Dosing descriptor(s) missing")
-  
+    stop(paste("Dosing descriptor(s) missing for route",
+               route, "in model",
+               model, ":",
+               unique(dosing_params)[!(unique(dosing_params) 
+                                       %in% names(dosing))]))
+ 
+  # Warn if unnecessary dosing_param provided:
+  if (any(!(names(dosing) %in% dosing_params)))
+    warning(paste("The following dosing descriptor(s) ignored for route",
+               route, "in model",
+               model, ":",
+               names(dosing)[!(names(dosing) 
+                                       %in% dosing_params)]))
+   
   #Provide default, somewhat arbitrary, single-time dosing case of
   #1 mg/kg BW for when no dosing is specified by user.
   if (all(as.logical(lapply(dosing, is.null)))) dosing$initial.dose <- 1 
@@ -662,8 +700,23 @@ specification in compartment_units for model ", model)
   # (2) get the potential volume tissue string with string update
   entry.tissue.string <- paste0(stringr::str_replace(dose.var,
                                                      pattern = "^A|^C",
-                                                     replacement = "V"),"c")
+                                                     replacement = "V"),"c")  
 
+  # Check if value "all" is used for a state (that is, all compartments are
+  # the same state of matter):
+  if (all(tolower(compartment_state[[1]])%in%"all"))
+  {
+    entry.compartment.state <- names(compartment_state)[1]
+  } else {
+    # Check whether the dose.var is in the compartment.state list & if so which
+    entry.state.check <- unlist(lapply(compartment_state,function(x){dose.var%in%x}))
+    if(any(entry.state.check)){
+      entry.compartment.state <- names(compartment_state)[which(entry.state.check==TRUE)]
+    }else{
+      stop(paste0("Entry compartment state is not specified in the model.list for ",model,"."))
+    }
+  }
+  
   # (3) Check if the tissue string is in all.tissue.vols,
   #     yes then get the provided parameter
   #     no then return null value
@@ -681,14 +734,14 @@ specification in compartment_units for model ", model)
   dosing.units <- input.units
   
   #Scale dose if input.units is measured in (mg/kg) 
-
   dosing <- scale_dosing(
     dosing,
     parameters,
     route,
     input.units = input.units,
     output.units = dose.units,
-    vol = entry.tissue.vol)
+    vol = entry.tissue.vol,
+    state = entry.compartment.state)
   dosing.units <- dose.units  #redefine the dosing units if scaling occurs
   
   #Extract our dosing parameters for use
